function Y = tscircminus(z,T)

%TSCIRCMINUS Circle Minus Operator
% TSCIRCMINUS(z,T) is implemented using the form specified by
% Theorem 2.7 of the Bohner-Peterson book.
%
% Circle Minus z = -z / (1 + z*h)
%
% where z is a scalar and h is mu.
%
% Brian Ballard, 08/17/05 Baylor University


type = size(T);

if (nargin < 2)
    error('Three arguments required')
elseif (nargin > 2)
    error('Too many arguments')
end

% Error Checking
if(nargin == 2)

    % Checking if T is a valid timescale 
    if(~isa(T,'timescale'))
        error('First argument must be a timescale object');
    end

    % Checking if z is numeric
    if(~isnumeric(z))
        error('First argument must be a number');
    end
end

h = tsmu(T);

% Actual Calculations

Y = -z ./ (1 + z * h);

% Add zero to the end of timescale?
